@@ -2053,6 +2053,7 @@ gs_flatpak_refine_app (GsFlatpak *self,
 		       GCancellable *cancellable,
 		       GError **error)
 {
+	AsAppState old_state = gs_app_get_state (app);
 	g_autoptr(AsProfileTask) ptask = NULL;
 
 	/* profile */
@@ -2084,6 +2085,12 @@ gs_flatpak_refine_app (GsFlatpak *self,
 		return FALSE;
 	}
 
+	/* if the state was changed, perhaps set the version from the release */
+	if (old_state != gs_app_get_state (app)) {
+		if (!gs_flatpak_refine_appstream (self, app, error))
+			return FALSE;
+	}
+
 	/* version fallback */
 	if (flags & GS_PLUGIN_REFINE_FLAGS_REQUIRE_VERSION) {
 		if (gs_app_get_version (app) == NULL) {
