@@ -22,12 +22,9 @@
 #ifndef __GS_SHELL_H
 #define __GS_SHELL_H
 
-#include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "gs-plugin-loader.h"
-#include "gs-category.h"
-#include "gs-app.h"
+#include "gnome-software-private.h"
 
 G_BEGIN_DECLS
 
@@ -99,6 +96,8 @@ void		 gs_shell_show_search_result	(GsShell	*shell,
 void		 gs_shell_show_extras_search	(GsShell	*shell,
 						 const gchar	*mode,
 						 gchar		**resources);
+void		 gs_shell_show_uri		(GsShell	*shell,
+						 const gchar	*url);
 void		 gs_shell_setup			(GsShell	*shell,
 						 GsPluginLoader	*plugin_loader,
 						 GCancellable	*cancellable);
